/// <reference types="node" />
import { IncomingMessage, ServerResponse } from 'http';
import { Worker } from './worker';
export interface HandlerOpts {
    secret: string;
}
export declare class WebhookHandler {
    private worker;
    constructor(worker: Worker);
    /**
     * Handles a request with a provided body, secret, and signature.
     *
     * @param {string | undefined} body - The body of the request.
     * @param {string | undefined} secret - The secret used for signature verification.
     * @param {string | string[] | undefined | null} signature - The signature of the request.
     *
     * @throws {HatchetError} - If no signature is provided or the signature is not a string.
     * @throws {HatchetError} - If no secret is provided.
     * @throws {HatchetError} - If no body is provided.
     */
    handle(body: string | undefined, secret: string | undefined, signature: string | string[] | undefined | null): Promise<void>;
    private getHealthcheckResponse;
    /**
     * Express Handler
     *
     * This method is an asynchronous function that returns an Express middleware handler.
     * The handler function is responsible for handling incoming requests and invoking the
     * corresponding logic based on the provided secret.
     *
     * @param {string} secret - The secret key used to authenticate and authorize the incoming requests.
     *
     * @return {Function} - An Express middleware handler function that receives the request and response objects.
     */
    expressHandler({ secret }: HandlerOpts): (req: any, res: any) => void;
    /**
     * A method that returns an HTTP request handler.
     *
     * @param {string} secret - The secret key used for verification.
     *
     * @returns {function} - An HTTP request handler function.
     */
    httpHandler({ secret }: HandlerOpts): (req: IncomingMessage, res: ServerResponse) => void;
    /**
     * A method that returns a Next.js request handler.
     *
     * @param {any} req - The request object received from Next.js.
     * @param {string} secret - The secret key used to verify the request.
     * @return {Promise<Response>} - A Promise that resolves with a Response object.
     */
    nextJSHandler({ secret }: HandlerOpts): {
        GET: () => Promise<Response>;
        POST: (req: Request) => Promise<Response>;
        PUT: (req: Request) => Promise<Response>;
    };
    private getBody;
}
