"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WebhookHandler = void 0;
const hatchet_error_1 = __importDefault(require("../../util/errors/hatchet-error"));
const crypto_1 = require("crypto");
const action_listener_1 = require("../dispatcher/action-listener");
class WebhookHandler {
    // eslint-disable-next-line no-useless-constructor,no-empty-function
    constructor(worker) {
        this.worker = worker;
    }
    /**
     * Handles a request with a provided body, secret, and signature.
     *
     * @param {string | undefined} body - The body of the request.
     * @param {string | undefined} secret - The secret used for signature verification.
     * @param {string | string[] | undefined | null} signature - The signature of the request.
     *
     * @throws {HatchetError} - If no signature is provided or the signature is not a string.
     * @throws {HatchetError} - If no secret is provided.
     * @throws {HatchetError} - If no body is provided.
     */
    handle(body, secret, signature) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!signature || typeof signature !== 'string') {
                throw new hatchet_error_1.default('No signature provided');
            }
            if (!secret) {
                throw new hatchet_error_1.default('No secret provided');
            }
            if (!body) {
                throw new hatchet_error_1.default('No body provided');
            }
            // verify hmac signature
            const actualSignature = (0, crypto_1.createHmac)('sha256', secret).update(body).digest('hex');
            if (actualSignature !== signature) {
                throw new hatchet_error_1.default(`Invalid signature, expected ${actualSignature}, got ${signature}`);
            }
            const action = action_listener_1.ActionObject.parse(JSON.parse(body));
            yield this.worker.handleAction(action);
        });
    }
    getHealthcheckResponse() {
        return {
            actions: Object.keys(this.worker.action_registry),
        };
    }
    /**
     * Express Handler
     *
     * This method is an asynchronous function that returns an Express middleware handler.
     * The handler function is responsible for handling incoming requests and invoking the
     * corresponding logic based on the provided secret.
     *
     * @param {string} secret - The secret key used to authenticate and authorize the incoming requests.
     *
     * @return {Function} - An Express middleware handler function that receives the request and response objects.
     */
    expressHandler({ secret }) {
        return (req, res) => {
            if (req.method === 'GET') {
                res.sendStatus(200);
                res.json(this.getHealthcheckResponse());
                return;
            }
            if (req.method !== 'POST') {
                res.sendStatus(405);
                res.json({ error: 'Method not allowed' });
                return;
            }
            this.handle(req.body, req.headers['x-hatchet-signature'], secret)
                .then(() => {
                res.sendStatus(200);
            })
                .catch((e) => {
                res.sendStatus(500);
                this.worker.logger.error(`Error handling request: ${e.message}`);
            });
        };
    }
    /**
     * A method that returns an HTTP request handler.
     *
     * @param {string} secret - The secret key used for verification.
     *
     * @returns {function} - An HTTP request handler function.
     */
    httpHandler({ secret }) {
        return (req, res) => {
            const handle = () => __awaiter(this, void 0, void 0, function* () {
                if (req.method === 'GET') {
                    res.writeHead(200, { 'Content-Type': 'application/json' });
                    res.write(JSON.stringify(this.getHealthcheckResponse()));
                    res.end();
                    return;
                }
                if (req.method !== 'POST') {
                    res.writeHead(405, { 'Content-Type': 'application/json' });
                    res.write(JSON.stringify({ error: 'Method not allowed' }));
                    res.end();
                    return;
                }
                const body = yield this.getBody(req);
                yield this.handle(body, secret, req.headers['x-hatchet-signature']);
                res.writeHead(200, 'OK');
                res.end();
            });
            handle().catch((e) => {
                this.worker.logger.error(`Error handling request: ${e.message}`);
                res.writeHead(500, 'Internal server error');
                res.end();
            });
        };
    }
    /**
     * A method that returns a Next.js request handler.
     *
     * @param {any} req - The request object received from Next.js.
     * @param {string} secret - The secret key used to verify the request.
     * @return {Promise<Response>} - A Promise that resolves with a Response object.
     */
    nextJSHandler({ secret }) {
        const healthcheck = () => __awaiter(this, void 0, void 0, function* () {
            return new Response(JSON.stringify(this.getHealthcheckResponse()), { status: 200 });
        });
        const f = (req) => __awaiter(this, void 0, void 0, function* () {
            yield this.handle(yield req.text(), secret, req.headers.get('x-hatchet-signature'));
            return new Response('ok', { status: 200 });
        });
        return {
            GET: healthcheck,
            POST: f,
            PUT: f,
        };
    }
    getBody(req) {
        return new Promise((resolve) => {
            let body = '';
            req.on('data', (chunk) => {
                body += chunk;
            });
            req.on('end', () => {
                resolve(body);
            });
        });
    }
}
exports.WebhookHandler = WebhookHandler;
